==> jc-1.4.0.tar.gz: soot/tagkit/BytecodeOffsetTag.h <==
// public class soot.tagkit.BytecodeOffsetTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a181128ef59b05a soot_tagkit_BytecodeOffsetTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_BytecodeOffsetTag_H_
#define _JC_soot_tagkit_BytecodeOffsetTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_BytecodeOffsetTag$sub_refs	_jc_soot_tagkit_BytecodeOffsetTag$sub_refs;
typedef struct _jc_soot_tagkit_BytecodeOffsetTag$sub_nonrefs	_jc_soot_tagkit_BytecodeOffsetTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_BytecodeOffsetTag$refs	_jc_soot_tagkit_BytecodeOffsetTag$refs;
typedef struct _jc_soot_tagkit_BytecodeOffsetTag$nonrefs	_jc_soot_tagkit_BytecodeOffsetTag$nonrefs;
typedef struct _jc_soot_tagkit_BytecodeOffsetTag$object	_jc_soot_tagkit_BytecodeOffsetTag$object;

typedef const struct _jc_soot_tagkit_BytecodeOffsetTag$vmethods	_jc_soot_tagkit_BytecodeOffsetTag$vmethods;
typedef const struct _jc_soot_tagkit_BytecodeOffsetTag$vtable	_jc_soot_tagkit_BytecodeOffsetTag$vtable;
typedef const struct _jc_soot_tagkit_BytecodeOffsetTag$vtype	_jc_soot_tagkit_BytecodeOffsetTag$vtype;

// Constructors
extern void _jc_soot_tagkit_BytecodeOffsetTag$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *, jint);

// Virtual methods
extern jint _jc_soot_tagkit_BytecodeOffsetTag$method$getBytecodeOffset$cd58e51a60fc3460(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_BytecodeOffsetTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *);
extern _jc_byte_array *_jc_soot_tagkit_BytecodeOffsetTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_BytecodeOffsetTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_BytecodeOffsetTag$method_info$getBytecodeOffset$cd58e51a60fc3460;
extern _jc_method _jc_soot_tagkit_BytecodeOffsetTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_BytecodeOffsetTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_BytecodeOffsetTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_BytecodeOffsetTag$vmethods {
	jint	(*getBytecodeOffset$cd58e51a60fc3460)(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *);
};

// Vtable
struct _jc_soot_tagkit_BytecodeOffsetTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_BytecodeOffsetTag$vmethods	soot_tagkit_BytecodeOffsetTag;
};

// Vtype
struct _jc_soot_tagkit_BytecodeOffsetTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_BytecodeOffsetTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_BytecodeOffsetTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_BytecodeOffsetTag$refs {
    _jc_soot_tagkit_BytecodeOffsetTag$sub_refs	soot_tagkit_BytecodeOffsetTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_BytecodeOffsetTag$sub_nonrefs {
	jint	offset;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_BytecodeOffsetTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_BytecodeOffsetTag$sub_nonrefs	soot_tagkit_BytecodeOffsetTag;
};

// Object instance structure
struct _jc_soot_tagkit_BytecodeOffsetTag$object {
	_jc_soot_tagkit_BytecodeOffsetTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_BytecodeOffsetTag$vtype	*vtype;
	_jc_soot_tagkit_BytecodeOffsetTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_BytecodeOffsetTag$vtype _jc_soot_tagkit_BytecodeOffsetTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_BytecodeOffsetTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_BytecodeOffsetTag$class_object;

#endif	/* _JC_soot_tagkit_BytecodeOffsetTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/BytecodeOffsetTag.h <==
// public class soot.tagkit.BytecodeOffsetTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a181128ef59b05a soot_tagkit_BytecodeOffsetTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_BytecodeOffsetTag_H_
#define _JC_soot_tagkit_BytecodeOffsetTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_BytecodeOffsetTag$sub_refs	_jc_soot_tagkit_BytecodeOffsetTag$sub_refs;
typedef struct _jc_soot_tagkit_BytecodeOffsetTag$sub_nonrefs	_jc_soot_tagkit_BytecodeOffsetTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_BytecodeOffsetTag$refs	_jc_soot_tagkit_BytecodeOffsetTag$refs;
typedef struct _jc_soot_tagkit_BytecodeOffsetTag$nonrefs	_jc_soot_tagkit_BytecodeOffsetTag$nonrefs;
typedef struct _jc_soot_tagkit_BytecodeOffsetTag$object	_jc_soot_tagkit_BytecodeOffsetTag$object;

typedef const struct _jc_soot_tagkit_BytecodeOffsetTag$vmethods	_jc_soot_tagkit_BytecodeOffsetTag$vmethods;
typedef const struct _jc_soot_tagkit_BytecodeOffsetTag$vtable	_jc_soot_tagkit_BytecodeOffsetTag$vtable;
typedef const struct _jc_soot_tagkit_BytecodeOffsetTag$vtype	_jc_soot_tagkit_BytecodeOffsetTag$vtype;

// Constructors
extern void _jc_soot_tagkit_BytecodeOffsetTag$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_tagkit_BytecodeOffsetTag$method$getBytecodeOffset$cd58e51a60fc3460(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_BytecodeOffsetTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_tagkit_BytecodeOffsetTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_BytecodeOffsetTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_BytecodeOffsetTag$method_info$getBytecodeOffset$cd58e51a60fc3460;
extern _jc_method _jc_soot_tagkit_BytecodeOffsetTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_BytecodeOffsetTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_BytecodeOffsetTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_BytecodeOffsetTag$vmethods {
	jint	(*getBytecodeOffset$cd58e51a60fc3460)(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_BytecodeOffsetTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_BytecodeOffsetTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_BytecodeOffsetTag$vmethods	soot_tagkit_BytecodeOffsetTag;
};

// Vtype
struct _jc_soot_tagkit_BytecodeOffsetTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_BytecodeOffsetTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_BytecodeOffsetTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_BytecodeOffsetTag$refs {
    _jc_soot_tagkit_BytecodeOffsetTag$sub_refs	soot_tagkit_BytecodeOffsetTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_BytecodeOffsetTag$sub_nonrefs {
	jint	offset;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_BytecodeOffsetTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_BytecodeOffsetTag$sub_nonrefs	soot_tagkit_BytecodeOffsetTag;
};

// Object instance structure
struct _jc_soot_tagkit_BytecodeOffsetTag$object {
	_jc_soot_tagkit_BytecodeOffsetTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_BytecodeOffsetTag$vtype	*vtype;
	_jc_soot_tagkit_BytecodeOffsetTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_BytecodeOffsetTag$vtype _jc_soot_tagkit_BytecodeOffsetTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_BytecodeOffsetTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_BytecodeOffsetTag$class_object;

#endif	/* _JC_soot_tagkit_BytecodeOffsetTag_H_ */
